@@ -4,9 +4,9 @@
  * Uses:      GTK+1.2, GdkImlib                                              *
  * Purpose:   Cut images at coordites this way, that they match each other.  *
  *            The matching can be controlled via certain view modes          *
- * Author:    Andreas Tille <tillea@rki.de>                                  *
- * Date:      May 03, 1999                                                   *
- * Copyright: Andreas Tille, 1998, 1999                                      *
+ * Author:    Andreas Tille <tille@debian.org>                                  *
+ * Date:      May 15, 2001                                                   *
+ * Copyright: Andreas Tille, 1998, 1999, 2000, 2001                          *
  * License:   LGPL                                                           *
  *                                                                           *
  *****************************************************************************/
@@ -38,7 +38,7 @@
 
 #include "gtkintl.h"
 
-static void gtk_immov_class_init     (GtkImMovClass *klass);
+static void gtk_immov_class_init     (GtkImMovClass *class);
 static void gtk_immov_init           (GtkImMov *immov);
 static void gtk_immov_destroy        (GtkObject *object);
 
