@@ -195,16 +195,16 @@ gtk_imreg_init (GtkImReg *imreg)
   gtk_box_pack_start(GTK_BOX(imreg->main_vbox), imreg->parms, TRUE, TRUE, 0);
   gtk_widget_show (imreg->parms);
 
-#define LABEL_WIDTH 65
+#define LABEL_WIDTH 85
   /**********************************************************************************
    * current cursor position                                                        *
    **********************************************************************************/
-  table = gtk_table_new (2, 2, /* homogeneous */ FALSE);
+  table = gtk_table_new (2, 3, /* homogeneous */ FALSE);
   gtk_container_set_border_width(GTK_CONTAINER(table), 5);
   gtk_box_pack_start(GTK_BOX(imreg->parms), table, TRUE, FALSE, 0);
   gtk_widget_show (table);
   
-  label = gtk_label_new(_("current:"));
+  label = gtk_label_new(_("curr:"));
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1, 0, 0, 0, 0);
   gtk_widget_show (label);
 
@@ -235,6 +235,23 @@ gtk_imreg_init (GtkImReg *imreg)
   imreg->size = gtk_label_new("");
   gtk_container_add(GTK_CONTAINER(frame), imreg->size);
   gtk_widget_show (imreg->size);
+  /**********************************************************************************
+   * current ration width/heigh                                                     *
+   **********************************************************************************/
+  label = gtk_label_new(_("w/h:"));
+  gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3, 0, 0, 0, 0);
+  gtk_widget_show (label);
+
+  frame = gtk_frame_new(NULL);
+  gtk_widget_set_usize(frame, LABEL_WIDTH, 0);
+  gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
+  gtk_table_attach(GTK_TABLE(table), frame, 1, 2, 2, 3, 0, 0, 0, 0);
+  gtk_widget_show (frame);
+
+  imreg->w2h = gtk_label_new("");
+  gtk_container_add(GTK_CONTAINER(frame), imreg->w2h);
+  gtk_widget_show (imreg->w2h);
+
 #undef LABEL_WIDTH 
 
   /**********************************************************************************
@@ -294,7 +311,7 @@ gtk_imreg_new (const gchar *title, GdkImlibImage *im, gint rw, gint rh, GtkWidge
 {
   GtkImReg     *imreg;
   GtkWidget    *table;
-  gchar        *buf;
+  gchar        *buf, *w2h;
   gint          max_right, max_bottom;
   register gint w, h;
   gchar        *unable = _("Unable to select region of %s %i from image of only %s %i."),
@@ -332,6 +349,7 @@ gtk_imreg_new (const gchar *title, GdkImlibImage *im, gint rw, gint rh, GtkWidge
     imreg->rw    = rw;
     imreg->rh    = rh;
     buf          = g_strdup_printf("%4ix%4i", imreg->rw, imreg->rh);
+    w2h          = g_strdup_printf("%#9g", (double)imreg->rw / (double)imreg->rh);
     imreg->r->le = (w - imreg->rw) >> 1;  
     imreg->r->to = (h - imreg->rh) >> 1;  
     imreg->r->ri = imreg->r->le + imreg->rw - 1;
@@ -343,6 +361,7 @@ gtk_imreg_new (const gchar *title, GdkImlibImage *im, gint rw, gint rh, GtkWidge
     imreg->rw    = w;
     imreg->rh    = h;
     buf          = g_strdup_printf("%4ix%4i", w, h);
+    w2h          = g_strdup_printf("%#9g", (double)w / (double)h);
     max_right    = w - 1;
     max_bottom   = h - 1;
     imreg->r->le = 0;
@@ -357,6 +376,8 @@ gtk_imreg_new (const gchar *title, GdkImlibImage *im, gint rw, gint rh, GtkWidge
   gtk_ruler_set_range(GTK_RULER(imreg->vruler), 0, h - 1, 0, w - 1);
   gtk_label_set(GTK_LABEL(imreg->size), buf);
   if ( buf ) g_free(buf);
+  gtk_label_set(GTK_LABEL(imreg->w2h), w2h);
+  if ( w2h ) g_free(w2h);
   
   /**********************************************************************************
    * editables for left and top position                                            *
@@ -944,6 +965,7 @@ _draw_rubber(GtkImReg *imreg)
 /* Draw the rubber box */
 {
   register int w, h;
+  gchar       *buf;
    
   g_return_if_fail ( imreg );
   g_return_if_fail ( GTK_IS_IMREG (imreg) );
@@ -981,13 +1003,18 @@ _draw_rubber(GtkImReg *imreg)
   
   g_return_if_fail ( GTK_IS_LABEL (imreg->size) );
   {
-    gchar *buf;
-     
     buf = g_strdup_printf("%4ix%4i", w + 1, h + 1);
     gtk_label_set(GTK_LABEL(imreg->size), buf);
     g_free(buf);
     gtk_widget_show(imreg->size);
   }
+  g_return_if_fail ( GTK_IS_LABEL (imreg->w2h) );
+  {
+    buf = g_strdup_printf("%#07g", (double)(w + 1) / (double)(h + 1));
+    gtk_label_set(GTK_LABEL(imreg->w2h), buf);
+    g_free(buf);
+    gtk_widget_show(imreg->w2h);
+  }
 }
 
 static void
