@@ -60,6 +60,8 @@ struct _GtkImReg
   GtkWidget      *cut;    /* drawable to show pixmap                       */
   GtkWidget      *pos;    /* Label to show current position                */
   GtkWidget      *size;   /* Label to show current size                    */
+  GtkWidget      *w2h;    /* Label to show width to height ratio           */
+  GtkWidget      *h2w;    /* Label to show height to width                 */
   GtkWidget      *hruler, *vruler;
   GtkWidget      *parms;  /* hbox with parameters                          */
   GtkWidget      *ok_button;
